@@ -44,6 +44,7 @@ struct org_kde_ksld;
 namespace ScreenLocker
 {
 class Unlocker;
+class WallpaperIntegration;
 
 class UnlockApp : public QGuiApplication
 {
@@ -59,6 +60,7 @@ public:
     void setGraceTime(int milliseconds);
     void setNoLock(bool noLock);
     void setKsldSocket(int socket);
+    void setDefaultToSwitchUser(bool defaultToSwitchUser);
 
     void osdProgress(const QString &icon, int percent, const QString &additionalText);
     void osdText(const QString &icon, const QString &additionalText);
@@ -83,6 +85,7 @@ private:
     void initialize();
     void initializeWayland();
     void shareEvent(QEvent *e, KQuickAddons::QuickViewSharedEngine *from);
+    void loadWallpaperPlugin(KQuickAddons::QuickViewSharedEngine *view);
 
     QString m_packageName;
     QUrl m_mainQmlPath;
@@ -97,6 +100,7 @@ private:
     Authenticator *m_authenticator;
     int m_graceTime;
     bool m_noLock;
+    bool m_defaultToSwitchUser;
 
     bool m_canSuspend = false;
     bool m_canHibernate = false;
@@ -107,6 +111,7 @@ private:
     org_kde_ksld *m_ksldInterface = nullptr;
 
     KWayland::Client::PlasmaShell *m_plasmaShell = nullptr;
+    WallpaperIntegration *m_wallpaperIntegration;
 };
 } // namespace
 
